from Products.validation.interfaces.IValidator import IValidator

from Products.CMFPlone import PloneMessageFactory as _
from Products.CMFCore.utils import getToolByName

from zope.interface import implements
from zope.i18n import translate

try: # Plone 4 and higher
    import plone.app.upgrade
    USE_BBB_VALIDATORS = False
except ImportError: # BBB Plone 3
    USE_BBB_VALIDATORS = True

class PositiveDimensionValidator:
    """Validates a Dimension
    """
    if USE_BBB_VALIDATORS: 
        __implements__ = (IValidator,)
    else:
        implements(IValidator)

    def __init__(self, name, title='', description=''):
        self.name = name
        self.title = title or name
        self.description = description

    def __call__(self, value, *args, **kw):
        error = str(_(u"Please enter a positive dimension"))
        try:
            int(value[0])
            int(value[1])
        except (ValueError, TypeError):
            return error
        if int(value[0]) < 0 or int(value[1]) < 0:
            return error
        return 1


from Products.validation import validation
from Products.CMFCore import utils, DirectoryView
from Products.DimensionWidget.config import *

from validator import PositiveDimensionValidator
validation.register(PositiveDimensionValidator('isPositiveDimension', title='', description=''))

DirectoryView.registerDirectory('skins', product_globals)


from Products.Archetypes.Widget import TypesWidget
from AccessControl import ClassSecurityInfo

class DimensionWidget(TypesWidget):
    _properties = TypesWidget._properties.copy()
    _properties.update({
        'macro' : 'dimension_widget',
        'size' : '5',
        'maxlength' : '255',
        'blurrable' : True,
        })

    security = ClassSecurityInfo()

    security.declarePublic('process_form')
    def process_form(self, instance, field, form, empty_marker=None,
                     emptyReturnsMarker=False, validating=True):
        """Basic impl for form processing in a widget"""
        value = form.get(field.getName(), empty_marker)
        value[0] = str(value[0])
        value[1] = str(value[1])
        return value, {}

    security.declarePublic('getWidth')
    def getWidth(self, value):
        try:
            return int(value[0])
        except:
            return 0

    security.declarePublic('getHeight')
    def getHeight(self, value):
        try:
            return int(value[1])
        except:
            return 0